==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/g_poll.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php
						if ($this->group_acs->checkPermission($resource_ids['group_poll'], $privilege_ids['allow_edit'])) { //resourece_id, Priv_id
						if (isset($poll['poll_id']) && (isset($poll['allow_edit']) || empty($comments))) {
						?>
						<a href="g_poll_edit.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $poll['poll_id'];?>" class="txt_sub_menu"><?php echo $lang['href_edit_this'];?></a><br />
						<?php 
						}
						if (!isset($poll['poll_id'])) {
						?>
						<a href="g_poll_edit.php?group_id=<?php echo $group['group_id'];?>" class="txt_sub_menu"><?php echo $lang['href_add'];?></a><br />
						<?php }}?>
						
						
						
						<?php
						if (isset($poll)) {
						?>
						<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>" class="txt_sub_menu"><?php echo $lang['href_list'];?></a><br />
						
						
						
						<?php
						if (isset($poll['bookmark']['watch'])) {
						?>
						<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $poll['poll_id'];?>&amp;unwatch=1" class="txt_sub_menu"><?php echo $lang['href_unwatch_this'];?></a><br />
						<?php
						}
						else {
						?>
						<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $poll['poll_id'];?>&amp;watch=1" class="txt_sub_menu"><?php echo $lang['href_watch_this'];?></a><br />
						<?php
						}
						?>

						<?php
						if (isset($poll['bookmark']['recommend'])) {
						?>
						<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $poll['poll_id'];?>&amp;unrecommend=1" class="txt_sub_menu"><?php echo $lang['href_unrecommend_this'];?></a><br />
						<?php
						}
						else {
						?>
						<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $poll['poll_id'];?>&amp;recommend=1" class="txt_sub_menu"><?php echo $lang['href_recommend_this'];?></a><br />
						<?php
						}
						?>
						<?php }?>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<?php
			if (isset($display) && $display == "view_polls") {
			?>
			
				<?php
				if (isset($forthcoming_polls)) {
				?>
				<table border="0" cellspacing="0" cellpadding="4" width="100%">
					<tr>
						<td colspan="3" class="txt_title" align="right">
							<?php echo $lang['hdr_forthcoming_polls'];?><br />
							<hr />
						</td>
					</tr>
					<?php
					foreach($forthcoming_polls as $key => $i):
					?>
					<tr>
						<td>
							<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $i['poll_id'];?>"><?php echo $i['poll_question'];?></a><br />
						</td>
						<td>
							<?php echo $i['display_poll_start_datetime'];?><br />
						</td>
						<td align="right">
							<?php echo $i['display_poll_end_datetime'];?><br />
						</td>
					</tr>
					<?php endforeach;?>
				</table>
				
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
				<?php }?>
				
				<table border="0" cellspacing="0" cellpadding="4" width="100%">
					<tr>
						<td colspan="3" class="txt_title" align="right">
							<?php echo $lang['hdr_polls'];?><br />
							<hr />
						</td>
					</tr>
					<?php
					if (isset($polls)) {
					foreach($polls as $key => $i):
					?>
					<tr>
						<td>
							<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $i['poll_id'];?>"><?php echo $i['poll_question'];?></a><br />
						</td>
						<td>
							<?php echo $i['display_poll_start_datetime'];?><br />
						</td>
						<td align="right">
							<?php echo $i['display_poll_end_datetime'];?><br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<table width="360" cellpadding="0" cellspacing="20" border="0">
								<tr>
									<td class="picture">
									<?php
									include $templatePath . "poll.inc.tpl.php";
									?>
									</td>
								</tr>
							</table>
						</td>
						<td>
							&nbsp;<br />
						</td>
				    </tr>
					<?php
					endforeach;
					}
					else {
					?>
					<tr>
						<td>
							<?php echo $lang['err_no_polls'];?><br />
						</td>
					</tr>
					<?php
					}
					?>
				</table>
				
				
				<?php
				if (isset($archive_polls)) {
				?>
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
				
				<table border="0" cellspacing="0" cellpadding="4" width="100%">
					<tr>
						<td colspan="3" class="txt_title" align="right">
							<?php echo $lang['hdr_archive_polls'];?><br />
							<hr />
						</td>
					</tr>
					<?php
					foreach($archive_polls as $key => $i):
					?>
					<tr>
						<td>
							<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $i['poll_id'];?>"><?php echo $i['poll_question'];?></a><br />
						</td>
						<td>
							<?php echo $i['display_poll_start_datetime'];?><br />
						</td>
						<td align="right">
							<?php echo $i['display_poll_end_datetime'];?><br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<table width="360" cellpadding="0" cellspacing="20" border="0">
								<tr>
									<td class="picture">
									<?php
									include $templatePath . "poll.inc.tpl.php";
									?>
									</td>
								</tr>
							</table>
						</td>
						<td>
							&nbsp;<br />
						</td>
				    </tr>
					<?php endforeach;?>
				</table>
				<?php }?>
				
			<?php
			}
			else {
			?>
				<table border="0" cellspacing="4" cellpadding="0" width="100%">
					<tr>
						<td colspan="2" class="txt_title" align="right">
							<?php echo $lang['hdr_poll'];?><br />
							<hr />
						</td>
					</tr>
					<tr>
						<td class="picture" valign="top">
							<?php
							include $templatePath . "poll_detail.inc.tpl.php";
							?>
						</td>
						<td valign="top" width="30%" class="picture">
							<table width="100%" cellpadding="4" cellspacing="0" border="0">
								<tr>
									<td valign="top">
										<b><?php echo $lang['hdr_vote_history'];?></b><br />
									</td>
								</tr>
								<?php
								if (isset($poll_history)) {
								foreach($poll_history as $key => $i):
								?>
								<tr>
									<td valign="top" class="txt_footer">
										<?php echo $i['answer_create_datetime'];?><br />
										<?php echo $i['option_body'];?><br />
									</td>
								</tr>
								<?php
								endforeach;
								}
								?>
							</table>
						</td>
				    </tr>
				</table>
			<?php }?>
			
			
			<?php
			if (isset($poll['poll_id'])) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
			
			<table width="100%" cellpadding="0" cellspacing="0" border="0">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['section_comments'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($comments)) {
				foreach($comments as $key => $i):
				?>
				<tr class="bg_2">
					<td>
						<table width="100%" cellpadding="4" cellspacing="0" border="0">
							<tr>
								<td class="txt_footer" colspan="2">
									<?php echo $lang['txt_from'];?>: <a href="g_member_profile.php?group_id=<?php echo $group['group_id'];?>&user_id=<?php echo $i['user_id'];?>" class="txt_footer_link"><?php echo $i['profile_nic'];?></a>&nbsp;(joined: <?php echo $i['profile_create_datetime'];?>, hometown: <?php echo $i['profile_hometown'];?>)<br />
									<?php echo $lang['txt_comment_datetime'];?>: <?php echo $i['comment_create_datetime'];?><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<?php echo $i['comment_body'];?><br />
								</td>
								<?php
								if (isset($poll) && empty($poll['poll_anon'])) {
								?>
								<td valign="top" align="right">
									<table cellpadding="2" cellspacing="0" border="0">
										<tr>
											<td valign="top" colspan="2">
												<?php echo $lang['hdr_vote_history'];?><br />
											</td>
										</tr>
										<?php
										if (isset($i['vote'])) {
										foreach($i['vote'] as $key => $r):
										?>
										<tr>
											<td valign="top" class="txt_footer">
												<?php echo $r['answer_create_datetime'];?><br />
											</td>
											<td valign="top" class="txt_footer">
												<?php echo $r['option_body'];?><br />
											</td>
										</tr>
										<?php
										endforeach;
										}
										?>
									</table>
								</td>
								<?php
								}
								?>
						    </tr>
						</table>
					</td>
				</tr>
				<tr>
					<td colspan="4">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr class="bg_2">
					<td colspan="2">
						<?php echo $lang['err_no_comments'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<?php
			if ($this->group_acs->checkPermission($resource_ids['group_poll'], $privilege_ids['allow_comment']) && empty($subject['subject_locked'])) {
			?>
			<?php
			if (isset($poll) && isset($poll['vote_required']) && !isset($poll['current_answer']['answer_id'])) {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr class="bg_2">
					<td colspan="2">
						<?php echo $lang['txt_poll_required'];?><br />
					</td>
				</tr>
			</table>

			<?php
			}
			else {
			?>
			<img src=<?php echo $templatePath;?>img/pixel.png width="1" height="20"><br />
			
			<form action="g_poll.php" method="post">
			<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" /><br />
			<input type="hidden" name="poll_id" value="<?php echo $poll['poll_id'];?>" /><br />
			<?php
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				if (isset($display) && $display == "preview_comment") {
				?>
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_comment_preview'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<input type="hidden" name="data[comment_body]" value="<?php echo $comment['comment_body'];?>" />
				
						<?php echo $comment['display_comment_body'];?><br />
					</td>
			    </tr>
				<tr>
					<td align="right">
						<input type="submit" name="edit_again" class="formInput" value="<?php echo $lang['sub_edit_again'];?>" />&nbsp;&nbsp;
						<input type="submit" name="insert" class="formInput" value="<?php echo $lang['sub_save'];?>" /><br />
					</td>
				</tr>
				<?php
				}
				else {
				?>

				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_add_comment'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_comment_help'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name="data[comment_body]" rows="5" cols="70" class="formInput"><?php if(isset($comment['comment_body'])) { echo $comment['comment_body'];}?></textarea><br />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_group_language'];?>: <?php echo $lang['arr_lang_name'][$group['language_id']];?><br />
					</td>
				</tr>
				<tr>
					<td align="right">
						<input type="submit" name="preview" class="formInput" value="<?php echo $lang['sub_preview'];?>">&nbsp;&nbsp;
						<input type="submit" name="insert" class="formInput" value="<?php echo $lang['sub_add'];?>"><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
			<?php
			}}
			else {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_add_comment'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_no_comment_allowed'];?><br />
					</td>
				</tr>
			</table>
			</form>
			<?php
			}}
			?>
		</td>
	</tr>
</table>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/aroundme_0_4_3/template/am_default/g_poll.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php
						if ($this->group_acs->checkPermission($resource_ids['group_poll'], $privilege_ids['allow_edit'])) { //resourece_id, Priv_id
						if (isset($poll['poll_id']) && (isset($poll['allow_edit']) || empty($comments))) {
						?>
						<a href="g_poll_edit.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $poll['poll_id'];?>" class="txt_sub_menu"><?php echo $lang['href_edit_this'];?></a><br />
						<?php 
						}
						if (!isset($poll['poll_id'])) {
						?>
						<a href="g_poll_edit.php?group_id=<?php echo $group['group_id'];?>" class="txt_sub_menu"><?php echo $lang['href_add'];?></a><br />
						<?php }}?>
						
						
						
						<?php
						if (isset($poll)) {
						?>
						<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>" class="txt_sub_menu"><?php echo $lang['href_list'];?></a><br />
						
						
						
						<?php
						if (isset($poll['bookmark']['watch'])) {
						?>
						<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $poll['poll_id'];?>&amp;unwatch=1" class="txt_sub_menu"><?php echo $lang['href_unwatch_this'];?></a><br />
						<?php
						}
						else {
						?>
						<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $poll['poll_id'];?>&amp;watch=1" class="txt_sub_menu"><?php echo $lang['href_watch_this'];?></a><br />
						<?php
						}
						?>

						<?php
						if (isset($poll['bookmark']['recommend'])) {
						?>
						<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $poll['poll_id'];?>&amp;unrecommend=1" class="txt_sub_menu"><?php echo $lang['href_unrecommend_this'];?></a><br />
						<?php
						}
						else {
						?>
						<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $poll['poll_id'];?>&amp;recommend=1" class="txt_sub_menu"><?php echo $lang['href_recommend_this'];?></a><br />
						<?php
						}
						?>
						<?php }?>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<?php
			if (isset($display) && $display == "view_polls") {
			?>
			
				<?php
				if (isset($forthcoming_polls)) {
				?>
				<table border="0" cellspacing="0" cellpadding="4" width="100%" class="table_stnd">
					<tr>
						<td colspan="3" class="txt_title" align="right">
							<?php echo $lang['hdr_forthcoming_polls'];?><br />
							<hr />
						</td>
					</tr>
					<?php
					foreach($forthcoming_polls as $key => $i):
					?>
					<tr>
						<td>
							<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $i['poll_id'];?>"><?php echo $i['poll_question'];?></a><br />
						</td>
						<td>
							<?php echo $i['display_poll_start_datetime'];?><br />
						</td>
						<td align="right">
							<?php echo $i['display_poll_end_datetime'];?><br />
						</td>
					</tr>
					<?php endforeach;?>
				</table>
				
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
				<?php }?>
				
				<table border="0" cellspacing="0" cellpadding="4" width="100%" class="table_stnd">
					<tr>
						<td colspan="3" class="txt_title" align="right">
							<?php echo $lang['hdr_polls'];?><br />
							<hr />
						</td>
					</tr>
					<?php
					if (isset($polls)) {
					foreach($polls as $key => $i):
					?>
					<tr>
						<td>
							<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $i['poll_id'];?>"><?php echo $i['poll_question'];?></a><br />
						</td>
						<td>
							<?php echo $i['display_poll_start_datetime'];?><br />
						</td>
						<td align="right">
							<?php echo $i['display_poll_end_datetime'];?><br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<table width="360" cellpadding="0" cellspacing="20" border="0" class="table_nested">
								<tr>
									<td class="picture">
									<?php
									include $templatePath . "poll.inc.tpl.php";
									?>
									</td>
								</tr>
							</table>
						</td>
						<td>
							&nbsp;<br />
						</td>
				    </tr>
					<?php
					endforeach;
					}
					else {
					?>
					<tr>
						<td>
							<?php echo $lang['err_no_polls'];?><br />
						</td>
					</tr>
					<?php
					}
					?>
				</table>
				
				
				<?php
				if (isset($archive_polls)) {
				?>
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
				
				<table border="0" cellspacing="0" cellpadding="4" width="100%" class="table_stnd">
					<tr>
						<td colspan="3" class="txt_title" align="right">
							<?php echo $lang['hdr_archive_polls'];?><br />
							<hr />
						</td>
					</tr>
					<?php
					foreach($archive_polls as $key => $i):
					?>
					<tr>
						<td>
							<a href="g_poll.php?group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $i['poll_id'];?>"><?php echo $i['poll_question'];?></a><br />
						</td>
						<td>
							<?php echo $i['display_poll_start_datetime'];?><br />
						</td>
						<td align="right">
							<?php echo $i['display_poll_end_datetime'];?><br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<table width="360" cellpadding="0" cellspacing="20" border="0" class="table_nested">
								<tr>
									<td class="picture">
									<?php
									include $templatePath . "poll.inc.tpl.php";
									?>
									</td>
								</tr>
							</table>
						</td>
						<td>
							&nbsp;<br />
						</td>
				    </tr>
					<?php endforeach;?>
				</table>
				<?php }?>
				
			<?php
			}
			else {
			?>
				<table border="0" cellspacing="4" cellpadding="0" width="100%" class="table_stnd">
					<tr>
						<td colspan="2" class="txt_title" align="right">
							<?php echo $lang['hdr_poll'];?><br />
							<hr />
						</td>
					</tr>
					<tr>
						<td class="picture" valign="top">
							<?php
							include $templatePath . "poll_detail.inc.tpl.php";
							?>
						</td>
						<td valign="top" width="30%" class="picture">
							<table width="100%" cellpadding="4" cellspacing="0" border="0" class="table_nested">
								<tr>
									<td valign="top">
										<b><?php echo $lang['hdr_vote_history'];?></b><br />
									</td>
								</tr>
								<?php
								if (isset($poll_history)) {
								foreach($poll_history as $key => $i):
								?>
								<tr>
									<td valign="top" class="txt_footer">
										<?php echo $i['answer_create_datetime'];?><br />
										<?php echo $i['option_body'];?><br />
									</td>
								</tr>
								<?php
								endforeach;
								}
								?>
							</table>
						</td>
				    </tr>
				</table>
			<?php }?>
			
			
			<?php
			if (isset($poll['poll_id'])) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
			
			<table width="100%" cellpadding="0" cellspacing="0" border="0" class="table_stnd">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['section_comments'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($comments)) {
				foreach($comments as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td class="txt_footer" colspan="2">
									<?php echo $lang['txt_from'];?>: <a href="g_member_profile.php?group_id=<?php echo $group['group_id'];?>&user_id=<?php echo $i['user_id'];?>" class="txt_footer_link"><?php echo $i['profile_nic'];?></a>&nbsp;(joined: <?php echo $i['profile_create_datetime'];?>, hometown: <?php echo $i['profile_hometown'];?>)<br />
									<?php echo $lang['txt_comment_datetime'];?>: <?php echo $i['comment_create_datetime'];?><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<?php echo $i['comment_body'];?><br />
								</td>
								<?php
								if (isset($poll) && empty($poll['poll_anon'])) {
								?>
								<td valign="top" align="right">
									<table cellpadding="2" cellspacing="0" border="0" class="table_nested">
										<tr>
											<td valign="top" colspan="2">
												<?php echo $lang['hdr_vote_history'];?><br />
											</td>
										</tr>
										<?php
										if (isset($i['vote'])) {
										foreach($i['vote'] as $key => $r):
										?>
										<tr>
											<td valign="top" class="txt_footer">
												<?php echo $r['answer_create_datetime'];?><br />
											</td>
											<td valign="top" class="txt_footer">
												<?php echo $r['option_body'];?><br />
											</td>
										</tr>
										<?php
										endforeach;
										}
										?>
									</table>
								</td>
								<?php
								}
								?>
						    </tr>
						</table>
					</td>
				</tr>
				<tr>
					<td colspan="4">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_comments'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<?php
			if ($this->group_acs->checkPermission($resource_ids['group_poll'], $privilege_ids['allow_comment']) && empty($subject['subject_locked'])) {
			?>
			<?php
			if (isset($poll) && isset($poll['vote_required']) && !isset($poll['current_answer']['answer_id'])) {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0" class="table_stnd">
				<tr>
					<td colspan="2">
						<?php echo $lang['txt_poll_required'];?><br />
					</td>
				</tr>
			</table>

			<?php
			}
			else {
			?>
			<img src=<?php echo $templatePath;?>img/pixel.png width="1" height="20"><br />
			
			<form action="g_poll.php" method="post">
			<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
			<input type="hidden" name="poll_id" value="<?php echo $poll['poll_id'];?>" />
			<?php
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0" class="table_stnd">
				<?php
				if (isset($display) && $display == "preview_comment") {
				?>
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_comment_preview'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<input type="hidden" name="data[comment_body]" value="<?php echo $comment['comment_body'];?>" />
				
						<?php echo $comment['display_comment_body'];?><br />
					</td>
			    </tr>
				<tr>
					<td align="right">
						<input type="submit" name="edit_again" class="formInput" value="<?php echo $lang['sub_edit_again'];?>" />&nbsp;&nbsp;
						<input type="submit" name="insert" class="formInput" value="<?php echo $lang['sub_save'];?>" /><br />
					</td>
				</tr>
				<?php
				}
				else {
				?>

				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_add_comment'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_comment_help'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name="data[comment_body]" rows="5" cols="70" class="formInput"><?php if(isset($comment['comment_body'])) { echo $comment['comment_body'];}?></textarea><br />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_group_language'];?>: <?php echo $lang['arr_lang_name'][$group['language_id']];?><br />
					</td>
				</tr>
				<tr>
					<td align="right">
						<input type="submit" name="preview" class="formInput" value="<?php echo $lang['sub_preview'];?>">&nbsp;&nbsp;
						<input type="submit" name="insert" class="formInput" value="<?php echo $lang['sub_add'];?>"><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
			<?php
			}}
			else {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0" class="table_stnd">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_add_comment'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_no_comment_allowed'];?><br />
					</td>
				</tr>
			</table>
			</form>
			<?php
			}}
			?>
		</td>
	</tr>
</table>
